==> webkit2gtk_2.51.2.orig.tar.xz: webkitgtk-2.51.2/Source/WebKit/Shared/JSHandleInfo.cpp <==
/*
 * Copyright (C) 2025 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "JSHandleInfo.h"

#include <wtf/TZoneMallocInlines.h>

namespace WebKit {

WTF_MAKE_STRUCT_TZONE_ALLOCATED_IMPL(JSHandleInfo);

JSHandleInfo::JSHandleInfo(WebCore::JSHandleIdentifier identifier, ContentWorldIdentifier worldIdentifier, FrameInfoData&& frameInfo, Markable<WebCore::FrameIdentifier> windowProxyFrameIdentifier)
    : identifier(identifier)
    , worldIdentifier(worldIdentifier)
    , frameInfo(WTFMove(frameInfo))
    , windowProxyFrameIdentifier(windowProxyFrameIdentifier) { }

bool JSHandleInfo::operator==(const JSHandleInfo& other) const
{
    // If these properties are equal, it implies the other properties are equal,
    // so we intentionally don't need to check their equality.
    return identifier == other.identifier
        && worldIdentifier == other.worldIdentifier;
}

} // namespace WebKit

==> webkit2gtk_2.51.92.orig.tar.xz: webkitgtk-2.51.92/Source/WebKit/Shared/JSHandleInfo.cpp <==
/*
 * Copyright (C) 2025 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "JSHandleInfo.h"

#include <wtf/TZoneMallocInlines.h>

namespace WebKit {

WTF_MAKE_STRUCT_TZONE_ALLOCATED_IMPL(JSHandleInfo);

JSHandleInfo::JSHandleInfo(WebCore::JSHandleIdentifier identifier, ContentWorldIdentifier worldIdentifier, FrameInfoData&& frameInfo, Markable<WebCore::FrameIdentifier> windowProxyFrameIdentifier)
    : identifier(identifier)
    , worldIdentifier(worldIdentifier)
    , frameInfo(WTF::move(frameInfo))
    , windowProxyFrameIdentifier(windowProxyFrameIdentifier) { }

bool JSHandleInfo::operator==(const JSHandleInfo& other) const
{
    // If these properties are equal, it implies the other properties are equal,
    // so we intentionally don't need to check their equality.
    return identifier == other.identifier
        && worldIdentifier == other.worldIdentifier;
}

} // namespace WebKit
